import format from 'date-fns/format';
import getMinutes from 'date-fns/getMinutes';
import isSameDay from 'date-fns/isSameDay';
const formatTemplate = 'ddd h:mma';
const dropSame = (dates, template, takeSecond = false, locale) => {
    const [first, second] = dates.map(date => format(date, template, { locale }));
    if (first !== second) {
        return [first, second];
    }
    if (takeSecond) {
        return ['', second];
    }
    return [first, ''];
};
const formatHour = (date, locale) => {
    if (getMinutes(date) === 0) {
        return format(date, 'h', { locale });
    }
    return format(date, 'h:mm', { locale });
};
export const getFormattedComponentsForDateRange = ({ dateRange, locale, template, template2, includeDayIfSame = true, }) => {
    const start = dateRange[0];
    const end = dateRange[dateRange.length - 1];
    if (isSameDay(start, end) && !template) {
        const [firstM, secondM] = dropSame(dateRange, 'a', true, locale);
        const day = includeDayIfSame ? `${format(start, 'ddd', { locale })} ` : '';
        return [
            `${day}${formatHour(start, locale)}${firstM}`,
            `${formatHour(end, locale)}${secondM}`,
        ];
    }
    const startDateStr = format(start, template || formatTemplate, { locale });
    const endDateStr = format(end, template2 || formatTemplate, { locale });
    return [startDateStr, endDateStr];
};
export const getTextForDateRange = (options) => {
    return getFormattedComponentsForDateRange(options).join(' – ');
};
//# sourceMappingURL=getTextForDateRange.js.map